summaryrefslogtreecommitdiffstats
path: root/kget/logwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kget/logwindow.cpp')
-rw-r--r--kget/logwindow.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kget/logwindow.cpp b/kget/logwindow.cpp
index 09490134..7ce11939 100644
--- a/kget/logwindow.cpp
+++ b/kget/logwindow.cpp
@@ -45,8 +45,8 @@
// res.simplifyWhiteSpace();
// int pos;
-// while ( (pos = res.find(' ')) != -1) {
-// res.replace(pos, 1, new TQChar( 0x00a0 ), 1);
+// while ( (pos = res.tqfind(' ')) != -1) {
+// res.tqreplace(pos, 1, new TQChar( 0x00a0 ), 1);
// }
// return res;
@@ -58,14 +58,14 @@ static TQString removeHTML(const TQString & str)
TQString res = str;
int pos;
- // replace <br/> with a newline
- while ((pos = res.find("<br/>")) != -1) {
- res.replace(pos, 4, "\n");
+ // tqreplace <br/> with a newline
+ while ((pos = res.tqfind("<br/>")) != -1) {
+ res.tqreplace(pos, 4, "\n");
}
// remove all tags
- while ((pos = res.find('<')) != -1) {
- int pos2 = res.find('>', pos);
+ while ((pos = res.tqfind('<')) != -1) {
+ int pos2 = res.tqfind('>', pos);
if (pos2 == -1) {
pos2 = res.length() + 1;
@@ -77,7 +77,7 @@ static TQString removeHTML(const TQString & str)
}
-SeparatedLog::SeparatedLog(TQWidget * parent):TQWidget(parent)
+SeparatedLog::SeparatedLog(TQWidget * tqparent):TQWidget(tqparent)
{
idSelected = 0;
@@ -112,7 +112,7 @@ SeparatedLog::SeparatedLog(TQWidget * parent):TQWidget(parent)
void SeparatedLog::addLog(uint id, const TQString & filename, const TQString & message)
{
- if (!trMap.contains(id)) {
+ if (!trMap.tqcontains(id)) {
trMap.insert(id, message);
TQListViewItem *last=lv_log->lastItem();
new TQListViewItem(lv_log, last);
@@ -200,7 +200,7 @@ void LogWindow::logTransfer(uint id, const TQString & filename, const TQString &
{
TQString mixed_msg, single_msg, job_id;
- job_id = TQString("Job[<font color=\"red\">%1</font>] : ").arg(id);
+ job_id = TQString("Job[<font color=\"red\">%1</font>] : ").tqarg(id);
mixed_msg = "<font color=\"blue\">" + TQTime::currentTime().toString() + "</font> : " + job_id + message;
single_msg = "<font color=\"blue\">" + TQTime::currentTime().toString() + "</font> : " + message;